<?php
/**
 * @since ningxia 1.0.0
**/

// Default the content width
if ( ! isset( $content_width ) ) $content_width = 900;

function ningxia_enqueue_styles() {
 $parent_style = 'ningxia-style';
 wp_enqueue_style( $parent_style, get_template_directory_uri().'/style.css', array(), '3.167.0');
}
add_action( 'wp_enqueue_scripts', 'ningxia_enqueue_styles' );

function ningxia_setup() {

	/*
	 * Make Twenty Fourteen available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on Twenty Fourteen, use a find and
	 * replace to change 'twentyfourteen' to the name of your theme in all
	 * template files.
	 */

	load_theme_textdomain( 'ningxia', get_template_directory() . '/languages' );

	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );

	register_nav_menus( array(
			'primary'  => __( 'Primary Navigation', 'ningxia'),
	) );

	/* Add title support */
	add_theme_support( 'title-tag' );
}
add_action( 'after_setup_theme', 'ningxia_setup' );

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since ningxia 1.0.0
 *
 * @return void
 */
function ningxia_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged			= get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link	= html_entity_decode( get_pagenum_link() );
	$query_args		= array();
	$url_parts		= explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
		'base'		=> $pagenum_link,
		'format'	=> $format,
		'total'		=> $GLOBALS['wp_query']->max_num_pages,
		'current'	=> $paged,
		'mid_size'	=> 1,
		'add_args'	=> array_map( 'urlencode', $query_args ),
		'prev_text'	=> __( '&larr; Previous', 'ningxia' ),
		'next_text'	=> __( 'Next &rarr;', 'ningxia' ),
	) );

	if ( $links ) :

	?>
		<div class="pagination loop-pagination">
			<?php echo $links; ?>
		</div><!-- .pagination -->
	<?php
	endif;
}

function ningxia_update_years() {
	$publish = (int)get_the_date( 'Y' );
	$modify = (int)get_the_modified_date( 'Y' );
	if ( isset( $GLOBALS['ningxia_year_publish'] ) ) {
		if ( $publish < $GLOBALS['ningxia_year_publish'] ) {
			$GLOBALS['ningxia_year_publish'] = $publish;
		}
	} else {
		$GLOBALS['ningxia_year_publish'] = $publish;
	}
	if ( isset( $GLOBALS['ningxia_year_modify'] ) ) {
		if ( $modify > $GLOBALS['ningxia_year_modify'] ) {
			$GLOBALS['ningxia_year_modify'] = $modify;
		}
	} else {
		$GLOBALS['ningxia_year_modify'] = $modify;
	}
}

function ningxia_scripts() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_script( 'ningxia-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '3.167.0', true );
}
add_action( 'wp_enqueue_scripts', 'ningxia_scripts' );

function ningxia_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() ) {
		return $title;
	}

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 ) {
		$title = "$title $sep " . sprintf( __( 'Page %s', 'ningxia' ), max( $paged, $page ) );
	}

	return $title;
}
add_filter( 'wp_title', 'ningxia_wp_title', 10, 2 );

function ningxia_widgets_init() {

	register_sidebar( array(
		'name'			=> __( 'Left Sidebar', 'ningxia' ),
		'id'			=> 'sidebar-left',
		'description'	=> __( 'Additional sidebar that appears on the left.', 'ningxia' ),
		'before_widget'	=> '<li id="%1$s" class="widget-container %2$s">',
		'after_widget'	=> '</li>',
		'before_title'	=> '<span class="widgettitle">',
		'after_title'	=> '</span>',
	) );
	register_sidebar( array(
		'name'			=> __( 'Right Sidebar', 'ningxia' ),
		'id'			=> 'sidebar-right',
		'description'	=> __( 'Main sidebar that appears on the right.', 'ningxia' ),
		'before_widget'	=> '<li id="%1$s" class="widget-container %2$s">',
		'after_widget'	=> '</li>',
		'before_title'	=> '<span class="widgettitle">',
		'after_title'	=> '</span>',
	) );
	register_sidebar( array(
		'name'			=> __('404 Page', 'ningxia'),
		'id'			=> '404-widgets',
		'description'	=> __( 'Widgets placed here will be shown on the 404 page.', 'ningxia' ),
		'before_widget'	=> '<div class="et_pb_post">',
		'after_widget'	=> '</div>',
		'before_title'	=> '<span class="widgettitle">',
		'after_title'	=> '</span>',
	) );
}
add_action( 'widgets_init', 'ningxia_widgets_init' );

// Disable texturize (smart quotes and a few other things)
add_filter( 'run_wptexturize', '__return_false' );
// Force a wp_texturize reset
$dummy = wptexturize("<p>",true);

function ningxia_title_apply_shortcodes($title, $sep) {
 return do_shortcode($title);
}
add_filter('wp_title', 'ningxia_title_apply_shortcodes', 10, 2);

function ningxia_remove_comment_reply_link_if_static($reply_link_html, $args, $comment, $post) {
	$static = ningxia_get_theme_option( 'static' );
	if ( $static == 'on' ) {
		$reply_link_html = '';
	}
	return $reply_link_html;
}
add_filter( 'comment_reply_link', 'ningxia_remove_comment_reply_link_if_static', 10, 4);

/* --------------------- Functions for updating themes ------------------------------ */
function ningxia_get_remote_update_from( $sitebase, $uploads, $slug ) {
	$url = $uploads . '/jsons/' . $slug . '.json';
	$remote =  wp_remote_get( $url, array( 'timeout' => 10, 'headers' => array( 'Accept' => 'application/json' ) ) );
	if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
		$remote['uploads'] = $uploads;
		$remote['sitebase'] = $sitebase;
	}
	return $remote;
}
function ningxia_get_remote_update_info( $slug ) {
	$remote = get_transient( 'djv_update_' . $slug );
	if (false == $remote || is_wp_error($remote) || !isset( $remote['response']['code'] ) || 200 !== $remote['response']['code'] || empty( $remote['body'] ) ) {
		$sitebase = get_site_url( );
		$upload_dir = wp_upload_dir( );
		if ( is_ssl() ) { $upload_dir['baseurl'] = str_replace( 'http://', 'https://', $upload_dir['baseurl'] ); }
		$remote = ningxia_get_remote_update_from( $sitebase, $upload_dir['baseurl'], $slug );
		if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
			set_transient( 'djv_update_' . $slug, $remote, 10 ); // Save for only 10 seconds here
		} else {
			$remote = ningxia_child_get_remote_update_from( 'https://blog.tremlas.com', 'https://blog.tremlas.com/wp-content/uploads', $slug );
			if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
				set_transient( 'djv_update_' . $slug, $remote, 43200 ); // Save for 12 hours
			}
		}
	}
	if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
		$body = json_decode( $remote['body'] );
		$changelog = $body->sections->changelog;
		$changelog = str_replace( '<a href="', '<a href="' . $remote['uploads'] . '/' , $changelog );
		$info = array(
				'name'			=> 'ningxia',
				'slug'			=> $slug,
				'version'		=> $body->version,
				'requires'		=> $body->requires,
				'author'		=> '<a href="' . $body->author_profile . '">' . $body->author . '</a>',
				'download_link'	=> $remote['uploads'] . '/' . $body->download_url,
				'trunk'			=> $remote['uploads'] . '/' . $body->download_url,
				'last_updated'	=> $body->last_updated,
				'sections'		=> array(
						'description'	=> implode( "\n", $body->sections->description ),
						'installation'	=> implode( "\n", $body->sections->installation ),
						'changelog'		=> implode( "\n", $changelog ),
				),
				'homepage'		=> $remote['sitebase'] . '/' . $body->homepage
		);
		return $info;
	}
	return false;
}

function ningxia_check_for_update( $slug ) {
	$info = ningxia_get_remote_update_info( $slug );
	if ( false == $info ) {
		return false;
	}
	if ( version_compare( '3.167.0', $info['version'], '<' ) && version_compare( $info['requires'], get_bloginfo( 'version' ), '<' ) ) {
		$update = array(
				'slug'			=> $slug,
				'new_version'	=> $info['version'],
				'url'			=> $info['homepage'],
				'package'		=> $info['download_link'],
				'icons'			=> array(),
				'banners'		=> array(),
				'banners_rtl'	=> array(),
				'tested'		=> '',
				'requires_php'	=> '',
				'compatability'	=> new StdClass()
		);
		return $update;
	} else {
		return false;
	}
}

function ningxia_pre_set_site_transient_update_themes( $transient ) {
	// Check for update
	$themeslug = 'ningxia';
	$update = ningxia_check_for_update( $themeslug );
	if ( $update ) {
		$transient->response[$themeslug] = $update;
	}
	return $transient;
}
add_filter( 'pre_set_site_transient_update_themes', 'ningxia_pre_set_site_transient_update_themes' );

function ningxia_theme_info( $result, $action, $args ) {
	$slug = 'ningxia';
	if ( 'plugin_information' !== $action ) {
		return $result;
	}
	if ( $slug !== $args->slug) {
		return $result;
	}
	return ningxia_get_remote_update_info( $slug );
}
add_filter( 'themes_api', 'ningxia_theme_info', 10, 3 );

/* ------------------------------ And load in the options ----------------------- */
require_once( __DIR__ . '/options.php');

?>